@@ -287,7 +287,8 @@ class MerginClient:
             if mp.inspect_files():
                 self.push_project(directory)
 
-    def projects_list(self, tags=None, user=None, flag=None, q=None):
+    def paginated_projects_list(self, page=1, per_page=50, tags=None, user=None, flag=None, name=None,
+                                namespace=None, order_params=None):
         """
         Find all available mergin projects.
 
@@ -300,6 +301,58 @@ class MerginClient:
         :param flag: Predefined filter flag ('created', 'shared')
         :type flag: String
 
+        :param name: Filter projects with name like name
+        :type name: String
+
+        :param namespace: Filter projects with namespace like namespace
+        :type namespace: String
+
+        :param page: Page number for paginated projects list
+        :type page: Integer
+
+        :param per_page: Number of projects fetched per page, max 100 (restriction set by server)
+        :type per_page: Integer
+
+        :param order_params: optional attributes for sorting the list. It should be a comma separated attribute names
+            with _asc or _desc appended for sorting direction. For example: "namespace_asc,disk_usage_desc".
+            Available attrs: namespace, name, created, updated, disk_usage, creator
+        :type order_params: String
+
+        :rtype: List[Dict]
+        """
+        params = {}
+        if tags:
+            params["tags"] = ",".join(tags)
+        if user:
+            params["user"] = user
+        if flag:
+            params["flag"] = flag
+        if name:
+            params["name"] = name
+        if namespace:
+            params["namespace"] = namespace
+        params["page"] = page
+        params["per_page"] = per_page
+        if order_params is not None:
+            params["order_params"] = order_params
+        resp = self.get("/v1/project/paginated", params)
+        projects = json.load(resp)
+        return projects
+
+    def projects_list(self, tags=None, user=None, flag=None, q=None):
+        """
+        Find all available Mergin projects. It will always retrieve max 100 projects.
+        Consider using the paginated_projects_list instead.
+
+        :param tags: Filter projects by tags ('valid_qgis', 'mappin_use', input_use')
+        :type tags: List
+
+        :param user: Username for 'flag' filter. If not provided, it means user executing request.
+        :type user: String
+
+        :param flag: Predefined filter flag ('created', 'shared')
+        :type flag: String
+
         :param q: Search query string
         :type q: String
 
