@@ -325,10 +325,15 @@ def pull_project_async(mc, directory):
     mp.log.info("--- version: " + mc.user_agent_info())
     mp.log.info(f"--- start pull {project_path}")
 
-    server_info = mc.project_info(project_path, since=local_version)
+    try:
+        server_info = mc.project_info(project_path, since=local_version)
+    except ClientError as err:
+        mp.log.error("Error getting project info: " + str(err))
+        mp.log.info("--- pull aborted")
+        raise
     server_version = server_info["version"]
 
-    mp.log.info(f"got project info. version {server_version}")
+    mp.log.info(f"got project info: local version {local_version} / server version {server_version}")
 
     if local_version == server_version:
         mp.log.info("--- pull - nothing to do (already at server version)")
@@ -437,6 +442,8 @@ def pull_project_is_running(job):
     """
     for future in job.futures:
         if future.done() and future.exception() is not None:
+            job.mp.log.error("Error while pulling data: " + str(future.exception()))
+            job.mp.log.info("--- pull aborted")
             raise future.exception()
         if future.running():
             return True
@@ -494,13 +501,20 @@ def pull_project_finalize(job):
     # make sure any exceptions from threads are not lost
     for future in job.futures:
         if future.exception() is not None:
+            job.mp.log.error("Error while pulling data: " + str(future.exception()))
+            job.mp.log.info("--- pull aborted")
             raise future.exception()
 
     job.mp.log.info("finalizing pull")
 
     # merge downloaded chunks
-    for file_to_merge in job.files_to_merge:
-        file_to_merge.merge()
+    try:
+        for file_to_merge in job.files_to_merge:
+            file_to_merge.merge()
+    except ClientError as err:
+        job.mp.log.error("Error merging chunks of downloaded file: " + str(err))
+        job.mp.log.info("--- pull aborted")
+        raise
 
     # make sure we can update geodiff reference files (aka. basefiles) with diffs or
     # download their full versions so we have them up-to-date for applying changes
@@ -517,6 +531,10 @@ def pull_project_finalize(job):
             # was also able to apply those diffs. It could be that someone modified
             # the basefile and we ended up in this inconsistent state.
             # let's remove the basefile and let the user retry - we should download clean version again
+            job.mp.log.error(f"Error patching basefile {basefile}")
+            job.mp.log.error("Diffs we were applying: " + str(diffs))
+            job.mp.log.error("Removing basefile because it would be corrupted anyway...")
+            job.mp.log.info("--- pull aborted")
             os.remove(basefile)
             raise ClientError("Cannot patch basefile {}! Please try syncing again.".format(basefile))
 
@@ -527,7 +545,7 @@ def pull_project_finalize(job):
         'files': job.project_info['files']
     }
 
-    job.mp.log.info("--- pull finished")
+    job.mp.log.info("--- pull finished -- at version " + job.mp.metadata['version'])
 
     shutil.rmtree(job.temp_dir)
     return conflicts
