@@ -26,6 +26,7 @@ def toggle_geodiff(enabled):
 def mc():
     return create_client(API_USER, USER_PWD)
 
+
 @pytest.fixture(scope='function')
 def mc2():
     return create_client(API_USER2, USER_PWD2)
@@ -64,8 +65,13 @@ def test_login(mc):
 
 
 def test_create_delete_project(mc):
-    # create new (empty) project on server
     test_project = 'test_create_delete'
+    project = API_USER + '/' + test_project
+    project_dir = os.path.join(TMP_DIR, test_project)
+    download_dir = os.path.join(TMP_DIR, 'download', test_project)
+
+    cleanup(mc, project, [project_dir, download_dir])
+    # create new (empty) project on server
     mc.create_project(test_project)
     projects = mc.projects_list(flag='created')
     assert any(p for p in projects if p['name'] == test_project and p['namespace'] == API_USER)
@@ -698,3 +704,35 @@ def test_download_versions(mc):
     # try to download not-existing version
     with pytest.raises(ClientError):
         mc.download_project(project, project_dir_v3, 'v3')
+
+
+def test_paginated_project_list(mc):
+    """Test the new endpoint for projects list with pagination, ordering etc."""
+    test_projects = dict()
+    for symb in "ABCDEF":
+        name = f"test_paginated_{symb}"
+        test_projects[name] = f"{API_USER}/{name}"
+
+    for name, full_name in test_projects.items():
+        cleanup(mc, full_name, [])
+        mc.create_project(name)
+
+    sorted_test_names = [n for n in sorted(test_projects.keys())]
+
+    resp = mc.paginated_projects_list(
+        flag='created', name="test_paginated", page=1, per_page=10, order_params="name_asc"
+    )
+    projects = resp["projects"]
+    count = resp["count"]
+    assert count == len(test_projects)
+    assert len(projects) == len(test_projects)
+    for i, project in enumerate(projects):
+        assert project["name"] == sorted_test_names[i]
+
+    resp = mc.paginated_projects_list(
+        flag='created', name="test_paginated", page=2, per_page=2, order_params="name_asc"
+    )
+    projects = resp["projects"]
+    assert len(projects) == 2
+    for i, project in enumerate(projects):
+        assert project["name"] == sorted_test_names[i+2]
